@@ -4,14 +4,14 @@ use warnings;
 use strict;
 use bytes;
 
-use IO::Compress::Base::Common  2.086 qw(:Status);
+use IO::Compress::Base::Common  2.088 qw(:Status);
 use IO::Compress::Zip::Constants ;
 
 our ($VERSION);
 
-$VERSION = '2.086';
+$VERSION = '2.088';
 
-use Compress::Raw::Zlib  2.086 ();
+use Compress::Raw::Zlib  2.088 ();
 
 sub mkUncompObject
 {
@@ -139,7 +139,7 @@ sub reset
 {
     my $self = shift;
 
-    $self->{CompSize}   = 0;
+    $self->{CompSize}->reset();
     $self->{UnCompSize} = 0;
     $self->{CRC32}      = Compress::Raw::Zlib::crc32('');
     $self->{ADLER32}    = Compress::Raw::Zlib::adler32('');      
