@@ -4,16 +4,16 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.083 ();
+use IO::Compress::Base::Common 2.088 ();
 
-use IO::Uncompress::Base 2.083 ;
+use IO::Uncompress::Base 2.088 ;
 
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyUncompressError);
 
-$VERSION = '2.083';
+$VERSION = '2.088';
 $AnyUncompressError = '';
 
 @ISA = qw(IO::Uncompress::Base Exporter);
@@ -29,24 +29,30 @@ BEGIN
 {
    local @INC = @INC;
    pop @INC if $INC[-1] eq '.';
-   eval ' use IO::Uncompress::Adapter::Inflate 2.083 ;';
-   eval ' use IO::Uncompress::Adapter::Bunzip2 2.083 ;';
-   eval ' use IO::Uncompress::Adapter::LZO 2.083 ;';
-   eval ' use IO::Uncompress::Adapter::Lzf 2.083 ;';
-   eval ' use IO::Uncompress::Adapter::UnLzma 2.083 ;';
-   eval ' use IO::Uncompress::Adapter::UnXz 2.083 ;';
-   eval ' use IO::Uncompress::Adapter::UnZstd 2.083 ;';
 
-   eval ' use IO::Uncompress::Bunzip2 2.083 ;';
-   eval ' use IO::Uncompress::UnLzop 2.083 ;';
-   eval ' use IO::Uncompress::Gunzip 2.083 ;';
-   eval ' use IO::Uncompress::Inflate 2.083 ;';
-   eval ' use IO::Uncompress::RawInflate 2.083 ;';
-   eval ' use IO::Uncompress::Unzip 2.083 ;';
-   eval ' use IO::Uncompress::UnLzf 2.083 ;';
-   eval ' use IO::Uncompress::UnLzma 2.083 ;';
-   eval ' use IO::Uncompress::UnXz 2.083 ;';
-   eval ' use IO::Uncompress::UnZstd 2.083 ;';
+   # Don't trigger any __DIE__ Hooks.
+   local $SIG{__DIE__};
+
+   eval ' use IO::Uncompress::Adapter::Inflate 2.088 ;';
+   eval ' use IO::Uncompress::Adapter::Bunzip2 2.088 ;';
+   eval ' use IO::Uncompress::Adapter::LZO 2.088 ;';
+   eval ' use IO::Uncompress::Adapter::Lzf 2.088 ;';
+   eval ' use IO::Uncompress::Adapter::UnLzma 2.088 ;';
+   eval ' use IO::Uncompress::Adapter::UnXz 2.088 ;';
+   eval ' use IO::Uncompress::Adapter::UnZstd 2.083 ;';
+   eval ' use IO::Uncompress::Adapter::UnLzip 2.088 ;';
+
+   eval ' use IO::Uncompress::Bunzip2 2.088 ;';
+   eval ' use IO::Uncompress::UnLzop 2.088 ;';
+   eval ' use IO::Uncompress::Gunzip 2.088 ;';
+   eval ' use IO::Uncompress::Inflate 2.088 ;';
+   eval ' use IO::Uncompress::RawInflate 2.088 ;';
+   eval ' use IO::Uncompress::Unzip 2.088 ;';
+   eval ' use IO::Uncompress::UnLzf 2.088 ;';
+   eval ' use IO::Uncompress::UnLzma 2.088 ;';
+   eval ' use IO::Uncompress::UnXz 2.088 ;';
+   eval ' use IO::Uncompress::UnZstd 2.088 ;';
+   eval ' use IO::Uncompress::UnLzip 2.088 ;';
 
 }
 
@@ -209,6 +215,24 @@ sub mkUncomp
 
          return 1;
      }
+
+
+     if (defined $IO::Uncompress::UnLzip::VERSION and
+            $magic = $self->ckMagic('UnLzip')) {
+
+        *$self->{Info} = $self->readHeader($magic)
+            or return undef ;
+
+        my ($obj, $errstr, $errno) = IO::Uncompress::Adapter::UnLzip::mkUncompObject(*$self->{Info}{DictSize});
+
+        return $self->saveErrorString(undef, $errstr, $errno)
+            if ! defined $obj;
+
+        *$self->{Uncomp} = $obj;
+
+         return 1;
+     }
+
      return 0 ;
 }
 
@@ -246,7 +270,7 @@ __END__
 
 =head1 NAME
 
-IO::Uncompress::AnyUncompress - Uncompress gzip, zip, bzip2 or lzop file/buffer
+IO::Uncompress::AnyUncompress - Uncompress gzip, zip, bzip2, xz, lzma, lzip, lzf or lzop file/buffer
 
 =head1 SYNOPSIS
 
@@ -317,6 +341,8 @@ The formats supported are:
 
 =item lzma
 
+=item lzip
+
 =item xz
 
 =back
@@ -341,7 +367,8 @@ The functional interface needs Perl5.005 or better.
 =head2 anyuncompress $input_filename_or_reference => $output_filename_or_reference [, OPTS]
 
 C<anyuncompress> expects at least two parameters,
-C<$input_filename_or_reference> and C<$output_filename_or_reference>.
+C<$input_filename_or_reference> and C<$output_filename_or_reference>
+and zero or more optional parameters (see L</Optional Parameters>)
 
 =head3 The C<$input_filename_or_reference> parameter
 
@@ -451,9 +478,9 @@ files/buffers.
 
 =head2 Optional Parameters
 
-Unless specified below, the optional parameters for C<anyuncompress>,
-C<OPTS>, are the same as those used with the OO interface defined in the
-L</"Constructor Options"> section below.
+The optional parameters for the one-shot function C<anyuncompress>
+are (for the most part) identical to those used with the OO interface defined in the
+L</"Constructor Options"> section. The exceptions are listed below
 
 =over 5
 
@@ -1022,9 +1049,15 @@ Same as doing this
 
 =head1 EXAMPLES
 
+=head1 SUPPORT
+
+General feedback/questions/bug reports should be sent to 
+L<https://github.com/pmqs/IO-Compress/issues> (preferred) or
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=IO-Compress>.
+
 =head1 SEE ALSO
 
-L<Compress::Zlib>, L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzma>, L<IO::Uncompress::UnLzma>, L<IO::Compress::Xz>, L<IO::Uncompress::UnXz>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Compress::Lzf>, L<IO::Uncompress::UnLzf>, L<IO::Uncompress::AnyInflate>
+L<Compress::Zlib>, L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzma>, L<IO::Uncompress::UnLzma>, L<IO::Compress::Xz>, L<IO::Uncompress::UnXz>, L<IO::Compress::Lzip>, L<IO::Uncompress::UnLzip>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Compress::Lzf>, L<IO::Uncompress::UnLzf>, L<IO::Compress::Zstd>, L<IO::Uncompress::UnZstd>, L<IO::Uncompress::AnyInflate>
 
 L<IO::Compress::FAQ|IO::Compress::FAQ>
 
@@ -1042,7 +1075,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2018 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2019 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
