@@ -9,12 +9,12 @@ our (@ISA, $VERSION, @EXPORT_OK, %EXPORT_TAGS);
 @ISA    = qw(IO::File Exporter);
 
 
-$VERSION = '2.083';
+$VERSION = '2.088';
 
 use constant G_EOF => 0 ;
 use constant G_ERR => -1 ;
 
-use IO::Compress::Base::Common 2.083 ;
+use IO::Compress::Base::Common 2.088 ;
 
 use IO::File ;
 use Symbol;
@@ -1010,6 +1010,9 @@ sub nextStream
     $status == 1
         or return $status ;
 
+    *$self->{Pending} = ''
+        if $self !~ /IO::Uncompress::RawInflate/ && ! *$self->{MultiStream};
+
     *$self->{TotalInflatedBytesRead} = 0 ;
     *$self->{LineNo} = $. = 0;
 
@@ -1050,6 +1053,10 @@ sub gotoNextStream
             return 0;
         }
 
+        # Not EOF, so Transparent mode kicks in now for trailing data
+        # Reset member name in case anyone calls getHeaderInfo()->{Name}
+        *$self->{Info} = { Name => undef, Type  => 'plain' };
+
         $self->clearError();
         *$self->{Type} = 'plain';
         *$self->{Plain} = 1;
@@ -1077,13 +1084,6 @@ sub streamCount
     return scalar @{ *$self->{InfoList} }  ;
 }
 
-#sub read
-#{
-#    my $status = myRead(@_);
-#    return undef if $status < 0;
-#    return $status;
-#}
-
 sub read
 {
     # return codes
@@ -1534,9 +1534,15 @@ IO::Uncompress::Base - Base Class for IO::Uncompress modules
 This module is not intended for direct use in application code. Its sole
 purpose is to be sub-classed by IO::Uncompress modules.
 
+=head1 SUPPORT
+
+General feedback/questions/bug reports should be sent to 
+L<https://github.com/pmqs/IO-Compress/issues> (preferred) or
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=IO-Compress>.
+
 =head1 SEE ALSO
 
-L<Compress::Zlib>, L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzma>, L<IO::Uncompress::UnLzma>, L<IO::Compress::Xz>, L<IO::Uncompress::UnXz>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Compress::Lzf>, L<IO::Uncompress::UnLzf>, L<IO::Uncompress::AnyInflate>, L<IO::Uncompress::AnyUncompress>
+L<Compress::Zlib>, L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzma>, L<IO::Uncompress::UnLzma>, L<IO::Compress::Xz>, L<IO::Uncompress::UnXz>, L<IO::Compress::Lzip>, L<IO::Uncompress::UnLzip>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Compress::Lzf>, L<IO::Uncompress::UnLzf>, L<IO::Compress::Zstd>, L<IO::Uncompress::UnZstd>, L<IO::Uncompress::AnyInflate>, L<IO::Uncompress::AnyUncompress>
 
 L<IO::Compress::FAQ|IO::Compress::FAQ>
 
@@ -1554,7 +1560,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2018 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2019 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
